# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'folder.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(320, 117)
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEdit = QtWidgets.QLineEdit(Dialog)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        self.btn_Browse = QtWidgets.QPushButton(Dialog)
        self.btn_Browse.setObjectName("btn_Browse")
        self.horizontalLayout.addWidget(self.btn_Browse)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.cancelButton = QtWidgets.QPushButton(Dialog)
        self.cancelButton.setAutoDefault(False)
        self.cancelButton.setObjectName("cancelButton")
        self.horizontalLayout_2.addWidget(self.cancelButton)
        self.acceptButton = QtWidgets.QPushButton(Dialog)
        self.acceptButton.setObjectName("acceptButton")
        self.horizontalLayout_2.addWidget(self.acceptButton)
        self.gridLayout.addLayout(self.horizontalLayout_2, 2, 0, 1, 1)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Set Folder"))
        self.label.setText(_translate("Dialog", "Folder:"))
        self.btn_Browse.setText(_translate("Dialog", "Browse"))
        self.cancelButton.setText(_translate("Dialog", "Cancel"))
        self.acceptButton.setText(_translate("Dialog", "Accept"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())



from folder_organizer.interfaces.mainwindow_ui import *
from folder_organizer.interfaces.new_ui import Ui_Dialog
from folder_organizer.interfaces.folder_ui import Ui_Dialog as Ui_Folder
import json
import sys
from folder_organizer.utils.organize import App
import multiprocessing
from PyQt5 import QtWidgets, QtGui, QtCore
from PyQt5.QtWidgets import QMessageBox
import folder_organizer.py_resources
from folder_organizer.constants import *
import os

class FolderWindow(QtWidgets.QDialog, Ui_Folder):
	def __init__(self):
		QtWidgets.QDialog.__init__(self)
		self.setupUi(self)

		self.cancelButton.clicked.connect(self.hide)
		self.acceptButton.clicked.connect(self.accept)
		self.btn_Browse.clicked.connect(self.browse)

		with open(resources / 'folder', 'r') as file:
			self.lineEdit.setText(file.read())
			file.close()

	def accept(self):
		with open(resources / 'folder', 'w') as file:
			file.write(self.lineEdit.text())
			file.close()
		self.hide()

	def browse(self):
		fileName = QtWidgets.QFileDialog.getExistingDirectory(self, 'Select directory')
		if fileName:
			self.lineEdit.setText(fileName)

class SecondWindow(QtWidgets.QDialog, Ui_Dialog):
	def __init__(self, mainw, mode, c=''):
		QtWidgets.QDialog.__init__(self)
		self.setupUi(self)

		self.mode = mode
		self.mainw = mainw
		self.id = c

		self.mainw.stop_program()

		self.cancelButton.clicked.connect(self.hide)
		self.acceptButton.clicked.connect(self.accept)
		self.nameEdit.returnPressed.connect(self.extEdit.setFocus)
		self.extEdit.returnPressed.connect(self.accept)

		if self.mode == 'edit':
			self.nameEdit.setText(self.mainw.data[self.id]['name'])
			self.extEdit.setText('; '.join(self.mainw.data[self.id]['ext']) + ';')

	def accept(self):
		if self.mode == 'new':
			self.mainw.data.append({'name': self.nameEdit.text(), 'ext': list(filter(lambda x: x != '' and x != ' ', self.extEdit.text().replace(' ', '').split(';')))})
			self.mainw.set_info()
			self.mainw.get_info()
			self.hide()

		elif self.mode == 'edit':
			self.mainw.data[self.id]['name'] = self.nameEdit.text()
			self.mainw.data[self.id]['ext'] = list(filter(lambda x: x != '' and x != ' ', self.extEdit.text().replace(' ', '').split(';')))
			self.mainw.set_info()
			self.mainw.get_info()
			self.hide()


class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
	def __init__(self):
		QtWidgets.QMainWindow.__init__(self)
		self.setupUi(self)

		self.organize_app = App()

		self.tree.setColumnWidth(0, 0)

		self.actionNewFilter.triggered.connect(self.new)
		self.actionEditFilter.triggered.connect(self.edit)
		self.actionDeleteFilter.triggered.connect(self.delete)

		self.actionSetFolder.triggered.connect(self.set_folder)
		self.actionStartProgram.triggered.connect(self.start_program)
		self.actionStopProgram.triggered.connect(self.stop_program)

		self.actionDestroy.triggered.connect(self.confirm_destroy)
		self.actionExit.triggered.connect(self.hide)

		self.get_info()

	def confirm_destroy(self):
		q = QMessageBox.question(self, 'Destroy program', "Are you sure?", QMessageBox.Yes | QMessageBox.No)
		if q == QMessageBox.Yes:
			self.stop_program()
			sys.exit()

	def closeEvent(self, event):
		self.hide()

	def new(self):
		self.new = SecondWindow(self, 'new')
		self.new.show()

	def edit(self):
		item = self.tree.currentItem()
		self.edit = SecondWindow(self, 'edit', int(item.text(0)))
		self.edit.show()

	def delete(self):
		item = self.tree.currentItem()
		del self.data[int(item.text(0))]
		self.set_info()
		self.get_info()

	def set_folder(self):
		self.set = FolderWindow()
		self.set.show()

	def stop_program(self):
		try:
			self.main_thread.terminate()
		except AttributeError:
			pass

	def start_program(self):
		self.stop_program()
		self.main_thread = multiprocessing.Process(target=self.organize_app.loop)
		self.main_thread.start()

	def get_info(self):
		with open(resources / 'data.json', 'r') as file:
			self.data = json.load(file)
			self.tree.clear()
			for i in range(len(self.data)):
				item = QtWidgets.QTreeWidgetItem()
				item.setText(0, str(i))
				item.setText(1, self.data[i]['name'])
				item.setText(2, '; '.join(self.data[i]['ext']) + ';')
				self.tree.addTopLevelItem(item)
			file.close()

	def set_info(self):
		with open(resources / 'data.json', 'w') as file:
			file.write(json.dumps(self.data))
			file.close()

def main():
	app = QtWidgets.QApplication([])
	window = MainWindow()

	app.setQuitOnLastWindowClosed(False)

	# Create the icon
	icon = QtGui.QIcon(":/images/icono")

	# Create the tray
	tray = QtWidgets.QSystemTrayIcon()
	tray.setIcon(icon)
	tray.setVisible(True)

	# Create the menu
	menu = QtWidgets.QMenu()
	action = QtWidgets.QAction("Open")
	action.triggered.connect(window.show)
	menu.addAction(action)

	# Add the menu to the tray
	tray.setContextMenu(menu)

	window.show()

	sys.exit(app.exec_())

if __name__ == '__main__':
	main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'new.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(182, 141)
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setGeometry(QtCore.QRect(10, 10, 47, 13))
        self.label.setObjectName("label")
        self.nameEdit = QtWidgets.QLineEdit(Dialog)
        self.nameEdit.setGeometry(QtCore.QRect(10, 30, 161, 20))
        self.nameEdit.setObjectName("nameEdit")
        self.label_2 = QtWidgets.QLabel(Dialog)
        self.label_2.setGeometry(QtCore.QRect(10, 60, 171, 16))
        self.label_2.setObjectName("label_2")
        self.extEdit = QtWidgets.QLineEdit(Dialog)
        self.extEdit.setGeometry(QtCore.QRect(10, 80, 161, 20))
        self.extEdit.setToolTip("")
        self.extEdit.setObjectName("extEdit")
        self.cancelButton = QtWidgets.QPushButton(Dialog)
        self.cancelButton.setGeometry(QtCore.QRect(10, 110, 75, 23))
        self.cancelButton.setAutoDefault(False)
        self.cancelButton.setObjectName("cancelButton")
        self.acceptButton = QtWidgets.QPushButton(Dialog)
        self.acceptButton.setGeometry(QtCore.QRect(100, 110, 75, 23))
        self.acceptButton.setAutoDefault(False)
        self.acceptButton.setObjectName("acceptButton")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "New"))
        self.label.setText(_translate("Dialog", "Name:"))
        self.nameEdit.setPlaceholderText(_translate("Dialog", "Example: Installers"))
        self.label_2.setText(_translate("Dialog", "Extensions (separated by ;)"))
        self.extEdit.setPlaceholderText(_translate("Dialog", "Example: exe; msi;"))
        self.cancelButton.setText(_translate("Dialog", "Calcel"))
        self.acceptButton.setText(_translate("Dialog", "Accept"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())



import folder_organizer.organizer as fo
from pathlib import Path
import os
import sys
import re


def main():
	pattern = r'python\d\d$'

	for i in sys.path:
		if re.search(pattern, i.lower()):
			path = i

	try:
		os.chdir(path)
	except UnboundLocalError:
		raise RuntimeError("Python folder is not in path")
	
	fo.main()

if __name__ == '__main__':
	main()


# from distutils.core import setup
import setuptools
import folder_organizer

setuptools.setup(
  name = 'folder-organizer',
  packages = [
    'folder_organizer',
    'folder_organizer.utils',
    'folder_organizer.interfaces',
    'folder_organizer.resources'
  ],
  version = '1.1',
  description = 'A simple folder organizer',
  author = 'Unai Minaberry y Avelino Navarro',
  author_email = 'unihernandez22@yahoo.com',
  url = 'https://github.com/unihernandez22/folder-organizer',
  download_url = 'https://github.com/unihernandez22/folder-organizer/tarball/0.1',
  keywords = ['organize', 'folders', 'files'],
  data_files = [('folder-organizer-resources', ['folder_organizer/resources/data.json', 'folder_organizer/resources/folder'])],
  install_requires=[
      'pyqt5',
  ],
  entry_points = {
        'console_scripts': [
            'folder-organizer=folder_organizer.open:main'
        ]
	}
)


import os
import json
from time import sleep
from shutil import move
from pathlib import Path
import sys
from folder_organizer.constants import *

class App:
	def __init__(self):
		with open(resources / 'folder', 'r') as f:
			a = f.read()
			self.folder = Path(a) if a != '' else ''
			f.close()

		with open(resources / 'data.json', 'r') as f:
			self.data = json.load(f)
			f.close()

	def loop(self):
		while True:
			if self.folder != '':
				self.organize(self.folder)
			sleep(5)

	def organize(self, folder):
		files = os.listdir(folder)
		if len(files) != 0:
			for file in files:
				ex = file.split('.')[-1]
				for i in self.data:
					if ex in i['ext']:
						try:
							move(folder / file, folder / f'{i["name"]}/{file}')
						except FileNotFoundError:
							os.mkdir(folder / i['name'])
							move(folder / file, folder / f'{i["name"]}/{file}')
						break

if __name__ == '__main__':
	App()


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(490, 321)
        self.centralWidget = QtWidgets.QWidget(MainWindow)
        self.centralWidget.setEnabled(True)
        self.centralWidget.setObjectName("centralWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralWidget)
        self.gridLayout.setObjectName("gridLayout")
        self.tree = QtWidgets.QTreeWidget(self.centralWidget)
        self.tree.setObjectName("tree")
        self.tree.header().setMinimumSectionSize(0)
        self.gridLayout.addWidget(self.tree, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralWidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 490, 21))
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setObjectName("menu")
        MainWindow.setMenuBar(self.menubar)
        self.actionNewFilter = QtWidgets.QAction(MainWindow)
        self.actionNewFilter.setObjectName("actionNewFilter")
        self.actionEdit_selected_filter = QtWidgets.QAction(MainWindow)
        self.actionEdit_selected_filter.setObjectName("actionEdit_selected_filter")
        self.actionEditFilter = QtWidgets.QAction(MainWindow)
        self.actionEditFilter.setObjectName("actionEditFilter")
        self.actionStartProgram = QtWidgets.QAction(MainWindow)
        self.actionStartProgram.setObjectName("actionStartProgram")
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionDeleteFilter = QtWidgets.QAction(MainWindow)
        self.actionDeleteFilter.setObjectName("actionDeleteFilter")
        self.actionSetFolder = QtWidgets.QAction(MainWindow)
        self.actionSetFolder.setObjectName("actionSetFolder")
        self.actionStopProgram = QtWidgets.QAction(MainWindow)
        self.actionStopProgram.setObjectName("actionStopProgram")
        self.actionDestroy = QtWidgets.QAction(MainWindow)
        self.actionDestroy.setObjectName("actionDestroy")
        self.menu.addAction(self.actionNewFilter)
        self.menu.addAction(self.actionEditFilter)
        self.menu.addAction(self.actionDeleteFilter)
        self.menu.addSeparator()
        self.menu.addAction(self.actionSetFolder)
        self.menu.addAction(self.actionStartProgram)
        self.menu.addAction(self.actionStopProgram)
        self.menu.addSeparator()
        self.menu.addAction(self.actionDestroy)
        self.menu.addAction(self.actionExit)
        self.menubar.addAction(self.menu.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Download Manager"))
        self.tree.headerItem().setText(0, _translate("MainWindow", "Id"))
        self.tree.headerItem().setText(1, _translate("MainWindow", "Name"))
        self.tree.headerItem().setText(2, _translate("MainWindow", "Extensions"))
        self.menu.setTitle(_translate("MainWindow", "Menu"))
        self.actionNewFilter.setText(_translate("MainWindow", "New filter"))
        self.actionEdit_selected_filter.setText(_translate("MainWindow", "Edit selected filter"))
        self.actionEditFilter.setText(_translate("MainWindow", "Edit selected filter"))
        self.actionStartProgram.setText(_translate("MainWindow", "Start program"))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
        self.actionDeleteFilter.setText(_translate("MainWindow", "Delete filter"))
        self.actionSetFolder.setText(_translate("MainWindow", "Set folder"))
        self.actionStopProgram.setText(_translate("MainWindow", "Stop program"))
        self.actionDestroy.setText(_translate("MainWindow", "Destroy"))
import folder_organizer.py_resources


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
